==> kubernetes-model-apiextensions-4.12.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/apiextensions/v1/WebhookConversionFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface WebhookConversionFluent<A extends WebhookConversionFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildClientConfig instead.
 * @return The buildable object.
 */
@Deprecated public WebhookClientConfig getClientConfig();
    public WebhookClientConfig buildClientConfig();
    public A withClientConfig(WebhookClientConfig clientConfig);
    public Boolean hasClientConfig();
    public WebhookConversionFluent.ClientConfigNested<A> withNewClientConfig();
    public WebhookConversionFluent.ClientConfigNested<A> withNewClientConfigLike(WebhookClientConfig item);
    public WebhookConversionFluent.ClientConfigNested<A> editClientConfig();
    public WebhookConversionFluent.ClientConfigNested<A> editOrNewClientConfig();
    public WebhookConversionFluent.ClientConfigNested<A> editOrNewClientConfigLike(WebhookClientConfig item);
    public A addToConversionReviewVersions(int index,String item);
    public A setToConversionReviewVersions(int index,String item);
    public A addToConversionReviewVersions(String... items);
    public A addAllToConversionReviewVersions(Collection<String> items);
    public A removeFromConversionReviewVersions(String... items);
    public A removeAllFromConversionReviewVersions(Collection<String> items);
    public List<String> getConversionReviewVersions();
    public String getConversionReviewVersion(int index);
    public String getFirstConversionReviewVersion();
    public String getLastConversionReviewVersion();
    public String getMatchingConversionReviewVersion(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public Boolean hasMatchingConversionReviewVersion(io.fabric8.kubernetes.api.builder.Predicate<String> predicate);
    public A withConversionReviewVersions(List<String> conversionReviewVersions);
    public A withConversionReviewVersions(String... conversionReviewVersions);
    public Boolean hasConversionReviewVersions();
    public A addNewConversionReviewVersion(String arg1);
    public A addNewConversionReviewVersion(StringBuilder arg1);
    public A addNewConversionReviewVersion(StringBuffer arg1);
    public interface ClientConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,WebhookClientConfigFluent<WebhookConversionFluent.ClientConfigNested<N>> {

        public N and();
        public N endClientConfig();    }


}

==> kubernetes-model-apiextensions-5.2.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/apiextensions/v1/WebhookConversionFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface WebhookConversionFluent<A extends WebhookConversionFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildClientConfig instead.
 * @return The buildable object.
 */
@Deprecated public WebhookClientConfig getClientConfig();
    public WebhookClientConfig buildClientConfig();
    public A withClientConfig(WebhookClientConfig clientConfig);
    public Boolean hasClientConfig();
    public WebhookConversionFluent.ClientConfigNested<A> withNewClientConfig();
    public WebhookConversionFluent.ClientConfigNested<A> withNewClientConfigLike(WebhookClientConfig item);
    public WebhookConversionFluent.ClientConfigNested<A> editClientConfig();
    public WebhookConversionFluent.ClientConfigNested<A> editOrNewClientConfig();
    public WebhookConversionFluent.ClientConfigNested<A> editOrNewClientConfigLike(WebhookClientConfig item);
    public A addToConversionReviewVersions(int index,String item);
    public A setToConversionReviewVersions(int index,String item);
    public A addToConversionReviewVersions(String... items);
    public A addAllToConversionReviewVersions(Collection<String> items);
    public A removeFromConversionReviewVersions(String... items);
    public A removeAllFromConversionReviewVersions(Collection<String> items);
    public List<String> getConversionReviewVersions();
    public String getConversionReviewVersion(int index);
    public String getFirstConversionReviewVersion();
    public String getLastConversionReviewVersion();
    public String getMatchingConversionReviewVersion(Predicate<String> predicate);
    public Boolean hasMatchingConversionReviewVersion(Predicate<String> predicate);
    public A withConversionReviewVersions(List<String> conversionReviewVersions);
    public A withConversionReviewVersions(String... conversionReviewVersions);
    public Boolean hasConversionReviewVersions();
    public A addNewConversionReviewVersion(String arg1);
    public A addNewConversionReviewVersion(StringBuilder arg1);
    public A addNewConversionReviewVersion(StringBuffer arg1);
    public interface ClientConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,WebhookClientConfigFluent<WebhookConversionFluent.ClientConfigNested<N>> {

            public N and();
            public N endClientConfig();    }


}
